@@ -2,6 +2,8 @@ from django.conf import settings
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 import smtplib
+from django.template.loader import render_to_string
+from django.http import HttpResponse
 
 
 def get_quarter_from_month(month):
@@ -33,4 +35,11 @@ def send_noreply_email(subject, message, recipient, from_name="Yeoki notificatio
 
     #NoReplyMail.objects.create(subject=subject, message=message, recipient=recipient)
 
-    return True
\ No newline at end of file
+    return True
+
+def render_multiple(request, template_names, context):
+    rendered_html = ""
+    for template_name in template_names:
+        rendered_html += render_to_string(template_name, context=context, request=request)
+
+    return HttpResponse(rendered_html)
